@@ -212,21 +212,26 @@ class SingleShotDetectorLearner(Learner):
                                     "ssd_512_vgg16_atrous_wider_person.json")
             if verbose:
                 print("Downloading metadata...")
-            urlretrieve(file_url, os.path.join(path, "ssd_default_person.json"))
+            file_path = os.path.join(path, "ssd_default_person.json")
+            if not os.path.exists(file_path):
+                urlretrieve(file_url, file_path)
 
             if verbose:
                 print("Downloading params...")
             file_url = os.path.join(url, "pretrained", "ssd_512_vgg16_atrous_wider_person",
                                     "ssd_512_vgg16_atrous_wider_person.params")
 
-            urlretrieve(file_url,
-                        os.path.join(path, "ssd_512_vgg16_atrous_wider_person.params"))
+            file_path = os.path.join(path, "ssd_512_vgg16_atrous_wider_person.params")
+            if not os.path.exists(file_path):
+                urlretrieve(file_url, file_path)
 
         elif mode == "images":
             file_url = os.path.join(url, "images", "people.jpg")
             if verbose:
                 print("Downloading example image...")
-            urlretrieve(file_url, os.path.join(path, "people.jpg"))
+            file_path = os.path.join(path, "people.jpg")
+            if not os.path.exists(file_path):
+                urlretrieve(file_url, file_path)
 
         elif mode == "test_data":
             os.makedirs(os.path.join(path, "test_data"), exist_ok=True)
@@ -236,17 +241,23 @@ class SingleShotDetectorLearner(Learner):
             file_url = os.path.join(url, "test_data", "train.txt")
             if verbose:
                 print("Downloading filelist...")
-            urlretrieve(file_url, os.path.join(path, "test_data", "train.txt"))
+            file_path = os.path.join(path, "test_data", "train.txt")
+            if not os.path.exists(file_path):
+                urlretrieve(file_url, file_path)
             # download image
             file_url = os.path.join(url, "test_data", "Images", "000040.jpg")
             if verbose:
                 print("Downloading image...")
-            urlretrieve(file_url, os.path.join(path, "test_data", "Images", "000040.jpg"))
+            file_path = os.path.join(path, "test_data", "Images", "000040.jpg")
+            if not os.path.exists(file_path):
+                urlretrieve(file_url, file_path)
             # download annotations
             file_url = os.path.join(url, "test_data", "Annotations", "000040.jpg.txt")
             if verbose:
                 print("Downloading annotations...")
-            urlretrieve(file_url, os.path.join(path, "test_data", "Annotations", "000040.jpg.txt"))
+            file_path = os.path.join(path, "test_data", "Annotations", "000040.jpg.txt")
+            if not os.path.exists(file_path):
+                urlretrieve(file_url, file_path)
 
     def reset(self):
         """This method is not used in this implementation."""
